<?php

/**
 * CUSTOM FUNCTIONS
 * @global moodle_database $DB
 */
function getConfig($name='', $plugin='nanogong')
{
    global $DB;

    $result = $DB->get_records('config_plugins', array('plugin' => $plugin));

    if ($name == '')
    {
        if (!empty($result))
        {
            $std = new stdClass();

            foreach ($result as $item)
            {
                $name = $item->name;
                $std->$name = $item->value;
            }
            return $std;
        }
    }
    else
    {
        if (!empty($result))
        {
            foreach ($result as $item)
            {
                if ($item->name == $name)
                {
                    $std = new stdClass();
                    $name = $item->name;
                    $std->$name = $item->value;
                    return $std;
                }
            }
        }
    }

    return false;
}

function getPlayerSettings($cmid='')
{
    $configDefault = getConfig();

    if ($cmid == '')
    {
        return $configDefault;
    }
    else
    {
        //geting the correct player settings
        //TODO get cmid relate information
        return $configDefault;
    }
}

function getNanogongPlayer($cmid='', $SoundFileURL='')
{
    global $CFG;
    $settings = getPlayerSettings($cmid);

    $player = '<applet id="nanogongApplet" archive="' . $CFG->wwwroot . '/mod/nanogong/nanogong.jar" code="gong.NanoGong" width="250" height="60">';

    if ($SoundFileURL != '')
    {
        $player .='<param name="ShowRecordButton" value="false" />
                    <param name="SoundFileURL" value="' . $SoundFileURL . '" />';
    }
    else
    {
        $player .='<param name="ShowRecordButton" value="true" />';
    }
    $player .='<param name="ShowSaveButton" value="' . $settings->showsavebutton . '" />
              <param name="ShowSpeedButton" value="' . $settings->showspeedbutton . '" />
              <param name="ShowAudioLevel" value="' . $settings->showaudiolevel . '" />
              <param name="SamplingRate" value="' . $settings->samplingrate . '" />
              <param name="SpeexQuality" value="' . $settings->speexquality . '" />
              <param name="Color" value="' . $settings->color . '" />
              <param name="ShowTime" value="' . $settings->showtime . '" />';

    $player .='</applet>';


    return $player;
}

/**
 * Display only in the resourses
 * @uses FEATURE_IDNUMBER
 * @uses FEATURE_GROUPS
 * @uses FEATURE_GROUPINGS
 * @uses FEATURE_GROUPMEMBERSONLY
 * @uses FEATURE_MOD_INTRO
 * @uses FEATURE_COMPLETION_TRACKS_VIEWS
 * @uses FEATURE_GRADE_HAS_GRADE
 * @uses FEATURE_GRADE_OUTCOMES
 * @param string $feature FEATURE_xx constant for requested feature
 * @return bool|null True if module supports feature, false if not, null if doesn't know
 */
function nanogong_supports($feature)
{
    switch ($feature)
    {
        case FEATURE_MOD_ARCHETYPE:           return MOD_ARCHETYPE_RESOURCE;
        case FEATURE_GROUPS:                  return false;
        case FEATURE_GROUPINGS:               return false;
        case FEATURE_GROUPMEMBERSONLY:        return true;
        case FEATURE_MOD_INTRO:               return true;
        case FEATURE_COMPLETION_TRACKS_VIEWS: return true;
        case FEATURE_GRADE_HAS_GRADE:         return false;
        case FEATURE_GRADE_OUTCOMES:          return false;
        case FEATURE_BACKUP_MOODLE2:          return false; // ;) YES found the perfect setting for prevending backup

        default: return null;
    }
}

/**
 * Returns all other caps used in module
 * @return array
 */
function nanogong_get_extra_capabilities()
{
    return array('moodle/site:accessallgroups');
}

/**
 * This function is used by the reset_course_userdata function in moodlelib.
 * @param $data the data submitted from the reset course.
 * @return array status array
 */
function nanogong_reset_userdata($data)
{
    return array();
}

/**
 * List of view style log actions
 * @return array
 */
function nanogong_get_view_actions()
{
    return array('view', 'view all');
}

/**
 * List of update style log actions
 * @return array
 */
function nanogong_get_post_actions()
{
    return array('update', 'add');
}

/**
 * Add resource instance.
 * @param object $data
 * @param object $mform
 * @return int new resoruce instance id
 */
function nanogong_add_instance($data, $mform)
{
    global $CFG, $DB;

    $fs = get_file_storage();
    $files = $fs->get_area_files($data->usercontextid, 'nanogong', 'nanogong_source', $data->time);

    foreach($files as $file)
    {
        if($file->get_filename()!='.')
        {
            $fileid = $file->get_id();
            break;
        }
    }

    $data2          = new stdClass();
    $data2->course  = $data->course;
    $data2->name    = $data->name;
    $data2->intro    = $data->intro;
    $data2->introformat= $data->introformat;
    $data2->timemodified= time();
    $data2->file_id     = $fileid;

    $id = $DB->insert_record('nanogong', $data2);

    return $id;
}

/**
 * Update resource instance.
 * @param object $data
 * @param object $mform
 * @return bool true
 */
function nanogong_update_instance($data, $mform)
{
    global $CFG, $DB;

    $fs = get_file_storage();
    $files = $fs->get_area_files($data->usercontextid, 'nanogong', 'nanogong_source', $data->time);

    foreach($files as $file)
    {
        if($file->get_filename()!='.')
        {
            $fileid = $file->get_id();
            break;
        }
    }

    $data2          = new stdClass();
    $data2->course  = $data->course;
    $data2->id      = $data->instance;
    $data2->name    = $data->name;
    $data2->intro    = $data->intro;
    $data2->introformat= $data->introformat;
    $data2->timemodified= time();

    if(!empty($fileid))
    {
        //we skip this if its empty and the file is not updated
        $data2->file_id     = $fileid;
    }
    
    $DB->update_record('nanogong', $data2);
    return true;
}

/**
 * Delete resource instance.
 * @param int $id
 * @return bool true
 */
function nanogong_delete_instance($id)
{
    global $DB;

    if (!$resource = $DB->get_record('nanogong', array('id' => $id)))
    {
        return false;
    }
    $fs = get_file_storage();
    $file =  $fs->get_file_by_id($resource->file_id);
    $file->delete();
    // note: all context files are deleted automatically

    $DB->delete_records('nanogong', array('id' => $resource->id));

    return true;
}

/**
 * Return use outline
 * @param object $course
 * @param object $user
 * @param object $mod
 * @param object $resource
 * @return object|null
 */
function nanogong_user_outline($course, $user, $mod, $resource)
{
    global $DB;

    if ($logs = $DB->get_records('log', array('userid' => $user->id, 'module' => 'nanogong', 'action' => 'view', 'info' => $resource->id), 'time ASC'))
    {

        $numviews = count($logs);
        $lastlog = array_pop($logs);

        $result = new stdClass();
        $result->info = get_string('numviews', '', $numviews);
        $result->time = $lastlog->time;

        return $result;
    }
    return NULL;
}

/**
 * Return use complete
 * @param object $course
 * @param object $user
 * @param object $mod
 * @param object $resource
 */
function nanogong_user_complete($course, $user, $mod, $resource)
{
    global $CFG, $DB;

    if ($logs = $DB->get_records('log', array('userid' => $user->id, 'module' => 'nanogong', 'action' => 'view', 'info' => $resource->id), 'time ASC'))
    {
        $numviews = count($logs);
        $lastlog = array_pop($logs);

        $strmostrecently = get_string('mostrecently');
        $strnumviews = get_string('numviews', '', $numviews);

        echo "$strnumviews - $strmostrecently " . userdate($lastlog->time);
    }
    else
    {
        print_string('neverseen', 'nanogong');
    }
}

/**
 * Returns the users with data in one resource
 *
 * @param int $resourceid
 * @return bool false
 */
function nanogong_get_participants($resourceid)
{
    return false;
}

function nanogong_display_embed($resource, $cm, $course, $file)
{
    global $CFG, $PAGE, $OUTPUT;

    if(!is_object($file))
    {
        //no file was created
        print_error('there_was_no_file_added');
    }

    $context = get_context_instance(CONTEXT_MODULE, $cm->id);

    $mimetype = $file->get_mimetype();
    $title    = $resource->name;

    resource_print_header($resource, $cm, $course);
    resource_print_heading($resource, $cm, $course);

      // resource_print_intro($resource, $cm, $course);
    echo $OUTPUT->heading($resource->name);
    echo $OUTPUT->box_start('mod_introbox', 'resourceintro');


    echo format_module_intro('nanogong', $resource, $cm->id);
    echo '<br/>';
    echo getNanogongPlayer($cm->id,  $CFG->wwwroot.'/mod/nanogong/view.php?id='.$cm->id.'&fileid='.$file->get_id());

    echo $OUTPUT->box_end();

    echo $OUTPUT->footer();
    die;
}
?>